@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.AppSync 1.17.72\n"
-        "Version:         1.17.72.post1\n"
+        "Type annotations for boto3.AppSync 1.17.76\n"
+        "Version:         1.17.76\n"
         "Builder version: 4.13.1\n"
         "Docs:            https://pypi.org/project/mypy-boto3-appsync/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/appsync.html#AppSync\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.76/reference/services/appsync.html#AppSync\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.72.post1")
+    print("1.17.76")
 
 
 def main() -> None:
